import { css, LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { styleMap } from 'lit/directives/style-map.js';

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
class UUILoaderCircleElement extends LitElement {
  constructor() {
    super(...arguments);
    this.largeSizes = ["l", "xl"];
    this.size = "s";
    this.progress = 0;
    this.showProgress = false;
  }
  strokeDashOffset() {
    if (this.progress) {
      return { strokeDasharray: `${this.progress}, 100` };
    } else {
      return { strokeDasharray: "100" };
    }
  }
  render() {
    return html`<div id="svg-container" class=${this.progress ? "" : "animate"}>
      <svg id="spinner" viewBox="0 0 40 40" xmlns="http://www.w3.org/2000/svg">
        <circle id="circle2" cx="50%" cy="50%" r="15.9155" />
        <circle
          id="circle"
          cx="50%"
          cy="50%"
          r="15.9155"
          style=${styleMap(this.strokeDashOffset())} />
      </svg>
      ${this.largeSizes.includes(this.size) && this.progress && this.showProgress ? html`<span id="progress-display">${this.progress}</span>` : ""}
    </div>`;
  }
}
UUILoaderCircleElement.styles = [
  css`
      :host {
        /* currently this components color is defined through currentColor, if we like to use a different color, we need to implemenet a --uui-interface- color which will be set/overwritten when looks are set, aka. if this element is used within a button with the look danger, then this component would get an appropriate color. */
        --uui-loader-circle-size: var(--uui-size-small, 12px);
        display: inline-block;
        vertical-align: middle;
      }

      :host([size='xs']) {
        --uui-loader-circle-size: var(--uui-size-xsmall, 9px);
      }

      :host([size='s']) {
        --uui-loader-circle-size: var(--uui-size-small, 12px);
      }

      :host([size='m']) {
        --uui-loader-circle-size: var(--uui-size-medium, 24px);
      }

      :host([size='l']) {
        --uui-loader-circle-size: var(--uui-size-large, 30px);
      }

      :host([size='xl']) {
        --uui-loader-circle-size: var(--uui-size-xlarge, 42px);
      }

      :host([size='xxl']) {
        --uui-loader-circle-size: var(--uui-size-xlarge, 66px);
      }

      #svg-container {
        overflow: hidden;
        display: inline-flex;
        justify-content: center;
        align-items: center;
        position: relative;
        width: var(--uui-loader-circle-size);
        height: var(--uui-loader-circle-size);
      }

      .animate #spinner {
        -webkit-animation: 3s linear infinite svg-animation;
                animation: 3s linear infinite svg-animation;
      }

      .animate #circle {
        -webkit-animation: 1.4s ease-in infinite circle-animation;
                animation: 1.4s ease-in infinite circle-animation;
      }

      #spinner {
        width: 100%;
      }

      #circle {
        display: block;
        fill: transparent;
        stroke: currentColor;
        stroke-linecap: round;
        stroke-dasharray: 0 301.592894745;

        stroke-width: 6px;
        transform-origin: 50% 50%;
        transform: rotate(-90deg);
        transition: stroke-dasharray 500ms ease;
      }

      #circle2 {
        fill: transparent;
        stroke: currentColor;
        stroke-width: 6px;
        opacity: 0.5;
      }

      #progress-display {
        position: absolute;
        left: 0;
        top: 50%;
        right: 0;
        stroke: currentColor;
        transform: translateY(-50%);
        font-size: 10px;
        font-weight: 700;
        text-align: center;
      }

      @-webkit-keyframes svg-animation {
        0% {
          transform: rotate(0deg);
        }
        100% {
          transform: rotate(360deg);
        }
      }

      @keyframes svg-animation {
        0% {
          transform: rotate(0deg);
        }
        100% {
          transform: rotate(360deg);
        }
      }

      @-webkit-keyframes circle-animation {
        0%,
        25% {
          stroke-dashoffset: 100;
          transform: rotate(0);
        }

        50%,
        75% {
          stroke-dashoffset: 20;
          transform: rotate(45deg);
        }

        100% {
          stroke-dashoffset: 100;
          transform: rotate(360deg);
        }
      }

      @keyframes circle-animation {
        0%,
        25% {
          stroke-dashoffset: 100;
          transform: rotate(0);
        }

        50%,
        75% {
          stroke-dashoffset: 20;
          transform: rotate(45deg);
        }

        100% {
          stroke-dashoffset: 100;
          transform: rotate(360deg);
        }
      }
    `
];
__decorateClass([
  property({ reflect: true })
], UUILoaderCircleElement.prototype, "size", 2);
__decorateClass([
  property({ type: Number })
], UUILoaderCircleElement.prototype, "progress", 2);
__decorateClass([
  property({ type: Boolean, reflect: true, attribute: "show-progress" })
], UUILoaderCircleElement.prototype, "showProgress", 2);

customElements.define("uui-loader-circle", UUILoaderCircleElement);
